Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Json = &jsonOutput{}
var Names []string
Names contains the names of all available output formats
var Outputs = []Output{ Yaml, Table, Json, }
Outputs contains all available output formatters
var Table = &tableOutput{}
var Yaml = &yamlOutput{}
Predefined output formatters
Functions ¶
This section is empty.
Types ¶
type Output ¶
type Output interface {
// GetName returns the name of the output format, will be used by the CLI to identify the output format.
GetName() string
// AsTable true if the kubernetes request should be made with the `application/json;as=Table;v=0.1` header.
AsTable() bool
// PrintObj prints the given object as a string.
PrintObj(obj interface{}) (string, error)
}
Output defines the interface for output formatters
func FromString ¶
FromString returns an output formatter by name
Click to show internal directories.
Click to hide internal directories.